<?php
/**
 * A class for managing custom active and inactive subscriber roles via a setting.
 *
 * @package WooCommerce Subscriptions
 * @since   4.0.0
 */

defined( 'ABSPATH' ) || exit;

class WCS_Subscriber_Role_Manager {

	/**
	 * Initialise the class.
	 */
	public static function init() {
		add_filter( 'woocommerce_subscription_settings', array( __CLASS__, 'add_settings' ), 20 );
	}

	/**
	 * Adds the subscription customer role setting.
	 *
	 * @since 4.0.0
	 *
	 * @param  array $settings Subscriptions settings.
	 * @return array Subscriptions settings.
	 */
	public static function add_settings( $settings ) {
		if ( ! function_exists( 'get_editable_roles' ) ) {
			require_once( ABSPATH . 'gc-admin/includes/user.php' );
		}

		foreach ( get_editable_roles() as $role => $details ) {
			$roles_options[ $role ] = translate_user_role( $details['name'] );
		}

		$role_settings = array(
			array(
				'name' => __( '身份', 'woocommerce-subscriptions' ),
				'type' => 'title',
				// translators: placeholders are <em> tags
				'desc' => sprintf( __( '选择要分配给有效和无效订阅者的默认角色。 为了保留记录，必须为订阅者创建一个用户帐户。 拥有%1$s管理员%2$s角色的用户（例如您自己）将永远不会分配到这些角色，这是为了防止锁定管理员。', 'woocommerce-subscriptions' ), '<em>', '</em>' ),
				'id'   => WC_Subscriptions_Admin::$option_prefix . '_role_options',
			),
			array(
				'name'     => __( '订阅者默认角色', 'woocommerce-subscriptions' ),
				'desc'     => __( '手动激活或成功购买后激活订阅后，将为新用户分配此角色。', 'woocommerce-subscriptions' ),
				'tip'      => '',
				'id'       => WC_Subscriptions_Admin::$option_prefix . '_subscriber_role',
				'css'      => 'min-width:150px;',
				'default'  => 'subscriber',
				'type'     => 'select',
				'options'  => $roles_options,
				'desc_tip' => true,
			),
			array(
				'name'     => __( '无效的订阅者角色', 'woocommerce-subscriptions' ),
				'desc'     => __( '如果订阅者的订阅被手动取消或过期，则将为其分配此角色。', 'woocommerce-subscriptions' ),
				'tip'      => '',
				'id'       => WC_Subscriptions_Admin::$option_prefix . '_cancelled_role',
				'css'      => 'min-width:150px;',
				'default'  => 'customer',
				'type'     => 'select',
				'options'  => $roles_options,
				'desc_tip' => true,
			),
			array(
				'type' => 'sectionend',
				'id'   => WC_Subscriptions_Admin::$option_prefix . '_role_options',
			),
		);

		WC_Subscriptions_Admin::insert_setting_after( $settings, WC_Subscriptions_Admin::$option_prefix . '_button_text', $role_settings, 'multiple_settings', 'sectionend' );
		return $settings;
	}

	/**
	 * Gets the subscriber role.
	 *
	 * @since 4.0.0
	 *
	 * @return string The role to apply to subscribers.
	 */
	public static function get_subscriber_role() {
		return get_option( WC_Subscriptions_Admin::$option_prefix . '_subscriber_role', 'subscriber' );
	}

	/**
	 * Gets the inactive subscriber role.
	 *
	 * @since 4.0.0
	 *
	 * @return string The role to apply to inactive subscribers.
	 */
	public static function get_inactive_subscriber_role() {
		return get_option( WC_Subscriptions_Admin::$option_prefix . '_cancelled_role', 'customer' );
	}
}
