<?php
/**
 * The template for displaying the early renewal modal.
 *
 * @since 2.6.0
 * @version 2.6.0
 * @var WC_Subscription  $subscription          The subscription being renewed early.
 * @var WC_DateTime|null $new_next_payment_date The subscription's new next payment date after if the subscription is renewed early. Will be a WC_DateTime object or null if no next payment will occur.
 * @var array            $totals                The subscription's totals array used to display the subscription totals table.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$include_item_removal_links = $include_switch_links = false;
?>
<div class="wcs_early_renew_modal_totals_table">
<?php do_action( 'woocommerce_subscription_totals', $subscription, $include_item_removal_links, $totals, $include_switch_links ); ?>
</div>
<p class="wcs_early_renew_modal_note">
<?php if ( ! empty( $new_next_payment_date ) ) {
	echo gc_kses_post( sprintf(
		__( '如果提前续订您的订阅，您的下次付款日期将为%s。', 'woocommerce-subscriptions' ),
		'<strong>' . esc_html( date_i18n( wc_date_format(), $new_next_payment_date->getOffsetTimestamp() ) ) . '</strong>'
	) );
} else {
	echo gc_kses_post( sprintf(
		__( '如果提前续订您的订阅，您预定于 %s完成的下一次付款将被取消。', 'woocommerce-subscriptions' ),
		'<strong>' . esc_html( date_i18n( wc_date_format(), $subscription->get_time( 'next_payment', 'site' ) ) ) . '</strong>'
	) );
}?>
</br>
<?php echo gc_kses_post( sprintf(
	__( '想通过结账提前续订？ 请点击%s此处。%s', 'woocommerce-subscriptions' ),
	'<a href="' . esc_url( wcs_get_early_renewal_url( $subscription ) ) . '">',
	'</a>'
) ) ?>
</p>
