<?php
/**
 * Upgrade helper template
 *
 * @author		Prospress
 * @category	Admin
 * @package		WooCommerce Subscriptions/Admin/Upgrades
 * @version		2.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
?>
<!DOCTYPE html>
<html xmlns="http://www.w3.org/1999/xhtml" <?php language_attributes(); ?>>
	<head>
		<meta http-equiv="Content-Type" content="<?php bloginfo( 'html_type' ); ?>; charset=<?php echo esc_attr( get_option( 'blog_charset' ) ); ?>" />
		<title><?php esc_html_e( '在线商城订阅更新', 'woocommerce-subscriptions' ); ?></title>
		<?php gc_admin_css( 'install', true ); ?>
		<?php gc_admin_css( 'ie', true ); ?>
		<?php gc_print_styles( 'wcs-upgrade' ); ?>
		<?php gc_print_scripts( 'jquery' ); ?>
		<?php gc_print_scripts( 'wcs-upgrade' ); ?>
	</head>
	<body class="gc-core-ui">
		<h1 id="logo"><img alt="在线商城订阅" width="325px" height="120px" src="<?php echo esc_url( wcs_get_image_asset_url( 'woocommerce_subscriptions_logo.png' ) ); ?>" /></h1>
		<div id="update-welcome">
			<h2><?php esc_html_e( '需要更新数据库', 'woocommerce-subscriptions' ); ?></h2>
			<p><?php esc_html_e( '在线商城订阅插件已更新！', 'woocommerce-subscriptions' ); ?></p>
			<p><?php
				// translators: placeholders are opening and closing tags
				printf( esc_html__( '我们需要先将您的数据库更新到最新版本，然后才能发送给您。 如果您没有站点的最新备份，%s赶快创建一个吧%s。', 'woocommerce-subscriptions' ), '<a target="_blank" href="https://codex.gechiui.com/Backing_Up_Your_Database">', '</a>' ); ?>
			</p>
			<?php if ( 'false' == $script_data['really_old_version'] ) : ?>
			<p><?php
				// translators: 1$: number of subscriptions on site, 2$, lower estimate (minutes), 3$: upper estimate
				printf( esc_html__( '您网站上 %1$d 个订阅的完整更新过程将在 %2$d 分钟到 %3$d 分钟之间完成。', 'woocommerce-subscriptions' ), esc_html( $subscription_count ), esc_html( round( $estimated_duration * 0.75 ) ), esc_html( round( $estimated_duration * 1.5 ) ) ); ?>
			</p>
			<?php else : ?>
			<p><?php esc_html_e( '更新过程可能需要花点时间，请耐心等待。', 'woocommerce-subscriptions' ); ?></p>
			<?php endif; ?>
			<p><?php esc_html_e( '在更新过程中，客户和其他非管理员用户可以继续在您的商店中浏览和购买产品。', 'woocommerce-subscriptions' ); ?></p>
			<form id="subscriptions-upgrade" method="get" action="<?php echo esc_url( admin_url( 'admin.php' ) ); ?>">
				<input type="submit" class="button" value="<?php echo esc_attr_x( '更新数据库', 'text on submit button', 'woocommerce-subscriptions' ); ?>">
			</form>
		</div>
		<div id="update-messages">
			<h2><?php esc_html_e( '正在更新', 'woocommerce-subscriptions' ); ?></h2>
			<p><?php esc_html_e( '在每批订阅更新后，此页面将显示该过程的结果。', 'woocommerce-subscriptions' ); ?></p>
			<p><?php esc_html_e( '请将此页面保持打开状态，直到更新过程完成。 无需刷新或重新启动该过程。', 'woocommerce-subscriptions' ); ?></p>
			<?php if ( isset( $estimated_duration ) && $estimated_duration > 20 ) : ?>
			<p><?php esc_html_e( '注意，尽管更新过程可能会花点时间，但在更新过程中，客户和其他非管理员用户可以继续在您的商店中浏览和购买产品。', 'woocommerce-subscriptions' ); ?></p>
			<?php endif; ?>
			<ol>
			</ol>
			<img id="update-ajax-loader" alt="loading..." width="16px" height="16px" src="<?php echo esc_url( wcs_get_image_asset_url( 'ajax-loader@2x.gif' ) ); ?>" />
			<p id="estimated_time"></p>
		</div>
		<div id="update-complete">
			<h2><?php esc_html_e( '升级完成', 'woocommerce-subscriptions' ); ?></h2>
			<p><?php esc_html_e( '您的数据库已成功更新！', 'woocommerce-subscriptions' ); ?></p>
			<p class="step"><a class="button" href="<?php echo esc_url( $about_page_url ); ?>"><?php esc_html_e( '继续', 'woocommerce-subscriptions' ); ?></a></p>
			<p class="log-notice"><?php
				// translators: $1: placeholder is number of weeks, 2$: path to the file
				echo gc_kses( sprintf( __( '为记录更新的进度，系统创建了一个新的日志文件。 此文件将在 %1$d 周后自动删除。 如果您想提前删除它，可以在此处找到它： %2$s', 'woocommerce-subscriptions' ), esc_html( WCS_Upgrade_Logger::$weeks_until_cleanup ), '<code class="log-notice">' . esc_html( wc_get_log_file_path( WCS_Upgrade_Logger::$handle ) ) . '</code>' ), array( 'code' => array( 'class' => true ) ) );
				?>
			</p>
		</div>
		<div id="update-error">
			<h2><?php esc_html_e( '更新错误', 'woocommerce-subscriptions' ); ?></h2>
			<p><?php esc_html_e( '更新出错。 请刷新该页面并重试。', 'woocommerce-subscriptions' ); ?></p>
		</div>
	</body>
</html>
