<?php
/**
 * The template for displaying an admin notice to report failed Subscriptions related scheduled actions.
 *
 * @version 2.5.0
 * @var array $failed_scheduled_actions
 * @var string $affected_subscription_events
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
// Get the log file URL depending on the log handler (file or database).
$url = admin_url( sprintf( 'admin.php?page=wc-status&tab=logs&log_file=%s-%s-log', 'failed-scheduled-actions', sanitize_file_name( gc_hash( 'failed-scheduled-actions' ) ) ) );

if ( defined( 'WC_LOG_HANDLER' ) && 'WC_Log_Handler_DB' === WC_LOG_HANDLER ) {
	$url = admin_url( sprintf( 'admin.php?page=wc-status&tab=logs&source=%s', 'failed-scheduled-actions' ) );
}
?>
<p><?php
	printf(
		esc_html( _n(
			'处理与最近的订阅相关的事件时出错。 有关如何修复受影响的订阅以及详细了解造成此错误的可能原因的步骤，请%1$s点击此处%2$s阅读我们的指南。',
			'An error has occurred while processing recent subscription related events. For steps on how to fix the affected subscriptions and to learn more about the possible causes of this error, please read our guide %1$shere%2$s.',
			count( $failed_scheduled_actions ),
			'woocommerce-subscriptions'
		) ),
		'<a href="https://docs.woocommerce.com/document/subscriptions/scheduled-action-errors/" target="_blank">',
		'</a>'
	)?>
</p>
<?php echo esc_html( _n( '受影响的事件：', 'Affected events:', count( $failed_scheduled_actions ) , 'woocommerce-subscriptions' ) ); ?>
<code style="display: block; white-space: pre-wrap"><?php
	echo gc_kses( $affected_subscription_events, array( 'a' => array( 'href' => array() ) ) ); ?>
</code>
<p><?php
	printf(
		// translators: $1 the log file name $2 and $3 are opening and closing link tags, respectively.
		esc_html__( '要查看有关这些错误的更多详细信息，请在 %2$s 在线商城日志屏幕中查看 %1$s 日志文件。%2$s','woocommerce-subscriptions' ),
		'<code>failed-scheduled-actions</code>',
		'<a href="' . esc_url( $url ) . '">',
		'</a>'
	);?>
</p>

